﻿using Arction.LightningChartUltimate;
using Arction.LightningChartUltimate.Axes;
using Arction.LightningChartUltimate.SeriesXY;
using Arction.LightningChartUltimate.Titles;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Runtime.Serialization.Formatters.Binary;
using System.Text;
using System.Windows.Forms;

namespace Playground
{
    public partial class BugTest : Form
    {
        // Chart:
        private LightningChartUltimate m_chart = null;
        PointLineSeries pls = null;
        AreaSeries areaSpectrum = null;

        AxisX axisSpectralX = null;
        AxisY axisSpectralY = null;
        AxisX axisX = null;
        AxisY axisY = null;

        public BugTest()
        {
            InitializeComponent();
            CreateChart();
            readData();
        }

        private void readData()
        {
            AreaSeriesPoint[] areaSeries;
            System.Xml.Serialization.XmlSerializer x = new System.Xml.Serialization.XmlSerializer(typeof(AreaSeriesPoint[]));
            Stream stream = File.Open("spectrum.xml", FileMode.Open);
            areaSeries = (AreaSeriesPoint[]) x.Deserialize(stream);
            stream.Close();

            areaSpectrum.AddValues(areaSeries, false);

            SeriesPoint[] pointSeries;
            System.Xml.Serialization.XmlSerializer x1 = new System.Xml.Serialization.XmlSerializer(typeof(SeriesPoint[]));
            Stream stream1 = File.Open("signal.xml", FileMode.Open);
            pointSeries = (SeriesPoint[])x1.Deserialize(stream1);
            stream1.Close();

            pls.AddPoints(pointSeries, false);
        }

        /// <summary>
        /// Create chart.
        /// </summary>
        private void CreateChart()
        {
            //Create new chart 
            m_chart = new LightningChartUltimate("Y3PT77S2RQRCKU6M6PR2EQ7XKJEHMSG9WHAZUQS5WQKADNQ49ZK2VG9E85KJSAEBBT6UJ8SCJSK5EX7VRMVHQER245MPUJXQESX99RAMMZ46Q89BT7A3MM8RM4M5AJCB7LTFJMWUVPZTLQLFADWCZRTBUTR4GZ5J538SJKZ");

            //Chart parent must be set
            m_chart.Parent = this;

            //Fill parent area with chart
            m_chart.Dock = DockStyle.Fill;

            //Chart name
            m_chart.Name = "A-Scan";

            m_chart.Title.Text = "";

            //Hide legend box
            m_chart.ViewXY.LegendBox.Visible = false;

            //Reduce memory usage and increase performance
            m_chart.ViewXY.DropOldSeriesData = false;

            m_chart.ViewXY.ZoomPanOptions.PanDirection = PanDirection.Horizontal;
            m_chart.ViewXY.ZoomPanOptions.MouseWheelZooming = MouseWheelZooming.Off;
            m_chart.ViewXY.ZoomPanOptions.ZoomRectLine.Color = Color.White;

            axisSpectralX = m_chart.ViewXY.XAxes[0];
            axisSpectralY = m_chart.ViewXY.YAxes[0];

            axisSpectralX.ValueType = AxisValueType.Number;

            axisSpectralX.Title.Visible = false;
            axisSpectralX.Title.Visible = false;

            m_chart.ViewXY.Margins = new Padding(40, 0, 10, 50);

            m_chart.Background.GradientFill = GradientFill.Solid;
            m_chart.Background.Color = Color.Black;
            m_chart.ViewXY.GraphBackground.Color = Color.Black;
            m_chart.ViewXY.GraphBackground.GradientFill = GradientFill.Solid;

            //Enable multi-core processing
            m_chart.RenderOptions.MultiCoreProcessing = MultiCoreProcessing.AllAvailableCores;
            m_chart.RenderOptions.MultiCoreCountLimit = (int)(System.Environment.ProcessorCount / 2 + 0.6);
            m_chart.RenderOptions.ViewXY.LineSeriesEnhancedAntiAliasing = EnhancedAntiAliasing.Off;

            axisX = new AxisX();
            axisX.SetRange(0, 2000);
            //axisX.RangeChanged += new AxisBase.RangeChangedHandler(XAxis_RangeChanged);
            axisX.MajorGrid.Color = Color.White;
            axisX.MajorGrid.Visible = false;
            axisX.Title = new AxisXTitle();
            axisX.Title.Text = "samples";
            axisX.Title.Font = new Font(axisX.Title.Font.FontFamily, 8f);
            axisX.Title.Color = Color.White;
            axisX.Title.VerticalAlign = XAxisTitleAlignmentVertical.Bottom;
            axisX.Title.HorizontalAlign = XAxisTitleAlignmentHorizontal.Right;
            axisX.Title.Visible = true;
            axisX.Title.DistanceToAxis = 24;
            axisX.LabelsVisible = true;
            axisX.LabelsPosition = Alignment.Far;
            axisX.LabelsColor = Color.White;
            axisX.ValueType = AxisValueType.Number;
            axisX.MinorGrid.Visible = false;
            axisX.MajorGrid.Visible = true;
            axisX.MajorGrid.PatternScale = 2;
            axisX.MajorGrid.Pattern = LinePattern.SmallDot;
            axisX.MajorGrid.Color = Color.DarkGray;
            m_chart.ViewXY.XAxes.Add(axisX);

            axisY = new AxisY();
            axisY.LabelsVisible = true;
            axisY.LabelsColor = Color.White;
            axisY.MinorGrid.Visible = false;
            axisY.MajorGrid.Color = Color.DarkGray;
            axisY.MajorGrid.Visible = true;
            axisY.MajorGrid.PatternScale = 2;
            axisY.MajorGrid.Pattern = LinePattern.SmallDot;
            m_chart.ViewXY.YAxes.Add(axisY);

            axisSpectralX.MouseScrolling = false;
            axisSpectralX.MouseScaling = true;
            axisSpectralX.MouseDragSnapToDiv = false;
            axisSpectralX.LabelsPosition = Alignment.Near;
            axisSpectralX.ValueType = AxisValueType.Number;
            axisSpectralX.LabelsColor = Color.LightGreen;
            axisSpectralX.Title.Text = "frequnecy[MHz]";
            axisSpectralX.Title.Font = new Font(axisX.Title.Font.FontFamily, 8f);
            axisSpectralX.Title.Color = Color.Green;
            axisSpectralX.Title.VerticalAlign = XAxisTitleAlignmentVertical.Bottom;
            axisSpectralX.Title.HorizontalAlign = XAxisTitleAlignmentHorizontal.Center;
            axisSpectralX.Title.Visible = true;
            axisSpectralX.Title.DistanceToAxis = 24;
            axisSpectralX.MinorGrid.Visible = false;
            axisSpectralX.MajorGrid.Visible = false;
            axisSpectralX.MajorDivTickStyle.Alignment = Alignment.Near;
            axisSpectralX.MajorDivTickStyle.Visible = true;
            axisSpectralX.MajorDivTickStyle.Color = Color.LightGreen;
            axisSpectralX.MinorDivTickStyle.Visible = false;

            axisSpectralY.MouseScrolling = false;
            axisSpectralY.MouseScaling = false;
            axisSpectralY.MouseDragSnapToDiv = false;
            axisSpectralY.SetRange(0, 1);
            axisSpectralY.LabelsVisible = false;
            axisSpectralY.MinorGrid.Visible = false;
            axisSpectralY.MajorGrid.Visible = false;
            axisSpectralY.MinorDivTickStyle.Visible = false;
            axisSpectralY.MajorDivTickStyle.Visible = false;

            pls = new PointLineSeries(m_chart.ViewXY, axisX, axisY);
            pls.PointsVisible = false;
            pls.MouseInteraction = false;
            pls.LineStyle.Width = 1f;
            pls.LineStyle.Color = Color.White;
            pls.MouseHighlight = MouseOverHighlight.Simple;
            pls.LineStyle.AntiAliasing = LineAntialias.Normal;
            pls.Title.Visible = false;
            pls.MouseInteraction = false;
            pls.LineStyle.Width = 1;
            pls.PointsVisible = false;
            pls.LineStyle.Pattern = LinePattern.Solid;
            pls.LineStyle.AntiAliasing = LineAntialias.None;
            m_chart.ViewXY.PointLineSeries.Add(pls);

            areaSpectrum = new AreaSeries(m_chart.ViewXY, axisSpectralX, axisSpectralY);
            areaSpectrum.LineStyle.AntiAliasing = LineAntialias.Normal;
            areaSpectrum.LineStyle.Color = Color.Green;
            areaSpectrum.LineStyle.Width = 1f;
            areaSpectrum.LineVisible = true;
            areaSpectrum.Fill.Color = Color.FromArgb(200, Color.Green);
            areaSpectrum.Fill.GradientColor = Color.FromArgb(200, ChartTools.CalcGradient(Color.Green, Color.Black, 80));
            areaSpectrum.MouseHighlight = MouseOverHighlight.None;
            areaSpectrum.MouseInteraction = false;
            areaSpectrum.Title.Visible = false;
            m_chart.ViewXY.AreaSeries.Add(areaSpectrum);
        }
    }
}
